package com.ruoyi.web.modules.trading.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Param;
import com.ruoyi.web.modules.trading.domain.BizMarketEntry;

/**
 * 市场进栏登记 Mapper
 */
public interface BizMarketEntryMapper
{
    BizMarketEntry selectBizMarketEntryById(Long id);

    BizMarketEntry selectBizMarketEntryByIdAny(Long id);

    List<BizMarketEntry> selectBizMarketEntryList(BizMarketEntry query);

    int insertBizMarketEntry(BizMarketEntry row);

    int updateBizMarketEntry(BizMarketEntry row);

    int logicDeleteBizMarketEntryByIds(@Param("ids") Long[] ids, @Param("updateBy") String updateBy);
}
